@@ -1,13 +1,10 @@
-import sys
-
 import click
-import opentelemetry.trace
 
 from mergify_cli import utils
 from mergify_cli.ci import detector
-from mergify_cli.ci import junit
-from mergify_cli.ci import quarantine
-from mergify_cli.ci import upload
+from mergify_cli.ci.junit_processing import cli as junit_processing_cli
+from mergify_cli.ci.scopes import cli as scopes_cli
+from mergify_cli.ci.scopes import exceptions as scopes_exc
 
 
 class JUnitFile(click.Path):
@@ -112,7 +109,7 @@ async def junit_upload(  # noqa: PLR0913
     tests_target_branch: str,
     files: tuple[str, ...],
 ) -> None:
-    await _process_junit_files(
+    await junit_processing_cli.process_junit_files(
         api_url=api_url,
         token=token,
         repository=repository,
@@ -183,7 +180,7 @@ async def junit_process(  # noqa: PLR0913
     tests_target_branch: str,
     files: tuple[str, ...],
 ) -> None:
-    await _process_junit_files(
+    await junit_processing_cli.process_junit_files(
         api_url=api_url,
         token=token,
         repository=repository,
@@ -194,137 +191,97 @@ async def junit_process(  # noqa: PLR0913
     )
 
 
-async def _process_junit_files(  # noqa: PLR0913
-    *,
+@ci.command(
+    help="""Give the list scope impacted by changed files""",
+    short_help="""Give the list scope impacted by changed files""",
+)
+@click.option(
+    "--config",
+    "config_path",
+    required=True,
+    type=click.Path(exists=True),
+    default=".mergify.yml",
+    help="Path to YAML config file.",
+)
+@click.option(
+    "--write",
+    "-w",
+    type=click.Path(),
+    help="Write the detected scopes to a file (json).",
+)
+def scopes(
+    config_path: str,
+    write: str | None = None,
+) -> None:
+    try:
+        scopes = scopes_cli.detect(config_path=config_path)
+    except scopes_exc.ScopesError as e:
+        raise click.ClickException(str(e)) from e
+
+    if write is not None:
+        scopes.save_to_file(write)
+
+
+@ci.command(help="Send scopes tied to a pull request to Mergify")
+@click.option(
+    "--api-url",
+    "-u",
+    help="URL of the Mergify API",
+    required=True,
+    envvar="MERGIFY_API_URL",
+    default="https://api.mergify.com",
+    show_default=True,
+)
+@click.option(
+    "--token",
+    "-t",
+    help="Mergify Key",
+    envvar="MERGIFY_TOKEN",
+    required=True,
+)
+@click.option(
+    "--repository",
+    "-r",
+    help="Repository full name (owner/repo)",
+    default=detector.get_github_repository,
+    required=True,
+)
+@click.option(
+    "--pull-request",
+    "-p",
+    help="pull_request number",
+    type=int,
+    default=detector.get_github_pull_request_number,
+    required=True,
+)
+@click.option("--scope", "-s", multiple=True, help="Scope to upload")
+@click.option(
+    "--file",
+    "-f",
+    help="File containing scopes to upload",
+    type=click.Path(exists=True),
+)
+@utils.run_with_asyncio
+async def scopes_send(  # noqa: PLR0913, PLR0917
     api_url: str,
     token: str,
     repository: str,
-    test_framework: str | None,
-    test_language: str | None,
-    tests_target_branch: str,
-    files: tuple[str, ...],
+    pull_request: int,
+    scope: tuple[str, ...],
+    file: str | None,
 ) -> None:
-    click.echo("🚀 CI Insights · Upload JUnit")
-    click.echo("────────────────────────────")
-    click.echo(f"📂 Discovered reports: {len(files)}")
+    scopes = list(scope)
+    if file is not None:
+        try:
+            dump = scopes_cli.DetectedScope.load_from_file(file)
+        except scopes_exc.ScopesError as e:
+            raise click.ClickException(str(e)) from e
+        scopes.extend(dump.scopes)
 
-    try:
-        spans = await junit.files_to_spans(
-            files,
-            test_language=test_language,
-            test_framework=test_framework,
-        )
-    except junit.InvalidJunitXMLError as e:
-        click.echo(
-            click.style(
-                f"❌ Error converting JUnit XML file to spans: {e.details}",
-                fg="red",
-            ),
-            err=True,
-        )
-        sys.exit(1)
-
-    if not spans:
-        click.echo(
-            click.style("❌ No spans found in the JUnit files", fg="red"),
-            err=True,
-        )
-        sys.exit(1)
-
-    tests_cases = [
-        span
-        for span in spans
-        if span.attributes is not None and span.attributes.get("test.scope") == "case"
-    ]
-
-    if not tests_cases:
-        click.echo(
-            click.style("❌ No test cases found in the JUnit files", fg="red"),
-            err=True,
-        )
-        sys.exit(1)
-
-    nb_failing_spans = len(
-        [
-            span
-            for span in tests_cases
-            if span.status.status_code == opentelemetry.trace.StatusCode.ERROR
-        ],
+    await scopes_cli.send_scopes(
+        api_url,
+        token,
+        repository,
+        pull_request,
+        scopes,
     )
-    nb_success_spans = len(
-        [
-            span
-            for span in tests_cases
-            if span.status.status_code == opentelemetry.trace.StatusCode.OK
-        ],
-    )
-    click.echo(
-        f"🧪 Parsed tests: {len(tests_cases)} (✅ passed: {nb_success_spans} | ❌ failed: {nb_failing_spans})",
-    )
-
-    # NOTE: Check quarantine before uploading in order to properly modify the
-    # "cicd.test.quarantined" attribute for the required spans.
-    quarantine_final_failure_message: str | None = None
-    try:
-        failing_tests_not_quarantined_count = (
-            await quarantine.check_and_update_failing_spans(
-                api_url,
-                token,
-                repository,
-                tests_target_branch,
-                spans,
-            )
-        )
-    except quarantine.QuarantineFailedError as exc:
-        click.echo(click.style(exc.message, fg="red"), err=True)
-        click.echo(
-            click.style(quarantine.QUARANTINE_INFO_ERROR_MSG, fg="red"),
-            err=True,
-        )
-        quarantine_final_failure_message = (
-            "Unable to determine quarantined failures due to above error"
-        )
-    except Exception as exc:  # noqa: BLE001
-        msg = (
-            f"❌ An unexpected error occurred when checking quarantined tests: {exc!s}"
-        )
-        click.echo(click.style(msg, fg="red"), err=True)
-        click.echo(
-            click.style(quarantine.QUARANTINE_INFO_ERROR_MSG, fg="red"),
-            err=True,
-        )
-        quarantine_final_failure_message = (
-            "Unable to determine quarantined failures due to above error"
-        )
-    else:
-        if failing_tests_not_quarantined_count > 0:
-            quarantine_final_failure_message = f"{failing_tests_not_quarantined_count} unquarantined failures detected ({nb_failing_spans - failing_tests_not_quarantined_count} quarantined)"
-
-    try:
-        upload.upload(
-            api_url=api_url,
-            token=token,
-            repository=repository,
-            spans=spans,
-        )
-    except Exception as e:  # noqa: BLE001
-        click.echo(
-            click.style(f"❌ Error uploading JUnit XML reports: {e}", fg="red"),
-            err=True,
-        )
-
-    if quarantine_final_failure_message is None:
-        click.echo("\n🎉 Verdict")
-        click.echo(
-            f"• Status: ✅ OK — all {nb_failing_spans} failures are quarantined (ignored for CI status)",
-        )
-        quarantine_exit_error_code = 0
-    else:
-        click.echo("\n❌ Verdict")
-        click.echo(
-            f"• Status: 🔴 FAIL — {quarantine_final_failure_message}",
-        )
-        quarantine_exit_error_code = 1
-
-    click.echo(f"• Exit code: {quarantine_exit_error_code}")
-    sys.exit(quarantine_exit_error_code)
