@@ -1,15 +1,17 @@
+import json
 import pathlib
 from unittest import mock
 
 import anys
 import click
 from click import testing
-from opentelemetry.sdk.trace import id_generator
 import pytest
+import respx
 
-from mergify_cli.ci import cli as cli_junit_upload
-from mergify_cli.ci import quarantine
-from mergify_cli.ci import upload
+from mergify_cli.ci import cli as ci_cli
+from mergify_cli.ci.junit_processing import cli as junit_processing_cli
+from mergify_cli.ci.junit_processing import quarantine
+from mergify_cli.ci.junit_processing import upload
 
 
 REPORT_XML = pathlib.Path(__file__).parent / "report.xml"
@@ -65,11 +67,11 @@ def test_cli(env: dict[str, str], monkeypatch: pytest.MonkeyPatch) -> None:
         ),
     ):
         result_process = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             [str(REPORT_XML)],
         )
         result_upload = runner.invoke(
-            cli_junit_upload.junit_upload,
+            ci_cli.junit_upload,
             [str(REPORT_XML)],
         )
     assert result_process.exit_code == 0, result_process.stdout
@@ -164,18 +166,18 @@ def test_tests_target_branch_environment_variable_processing(
     runner = testing.CliRunner()
 
     with mock.patch.object(
-        cli_junit_upload,
-        "_process_junit_files",
+        junit_processing_cli,
+        "process_junit_files",
         mock.AsyncMock(),
     ) as mocked_process_junit_files:
         result = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             [str(REPORT_XML)],
         )
 
     assert result.exit_code == 0, result.stdout
 
-    # Check that _process_junit_files was called with the expected branch
+    # Check that process_junit_files was called with the expected branch
     assert mocked_process_junit_files.call_count == 1
     call_kwargs = mocked_process_junit_files.call_args.kwargs
     assert call_kwargs["tests_target_branch"] == expected_branch
@@ -209,7 +211,7 @@ def test_quarantine_unhandled_error(monkeypatch: pytest.MonkeyPatch) -> None:
         ) as mocked_quarantine,
     ):
         result = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             [str(REPORT_XML)],
         )
 
@@ -258,7 +260,7 @@ def test_quarantine_handled_error(monkeypatch: pytest.MonkeyPatch) -> None:
         ) as mocked_quarantine,
     ):
         result = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             [str(REPORT_XML)],
         )
     assert result.exit_code == 1, (result.stdout, result.stderr)
@@ -307,7 +309,7 @@ def test_upload_error(monkeypatch: pytest.MonkeyPatch) -> None:
     ):
         mocked_upload.side_effect = Exception("Upload failed")
         result = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             [str(REPORT_XML)],
         )
     assert result.exit_code == 0, (result.stdout, result.stderr)
@@ -329,7 +331,7 @@ def test_process_tests_target_branch_callback() -> None:
 
     # Test stripping refs/heads/ prefix
     assert (
-        cli_junit_upload._process_tests_target_branch(
+        ci_cli._process_tests_target_branch(
             context_mock,
             param_mock,
             "refs/heads/main",
@@ -337,7 +339,7 @@ def test_process_tests_target_branch_callback() -> None:
         == "main"
     )
     assert (
-        cli_junit_upload._process_tests_target_branch(
+        ci_cli._process_tests_target_branch(
             context_mock,
             param_mock,
             "refs/heads/feature-branch",
@@ -347,7 +349,7 @@ def test_process_tests_target_branch_callback() -> None:
 
     # Test not stripping other prefixes
     assert (
-        cli_junit_upload._process_tests_target_branch(
+        ci_cli._process_tests_target_branch(
             context_mock,
             param_mock,
             "refs/tags/v1.0.0",
@@ -355,7 +357,7 @@ def test_process_tests_target_branch_callback() -> None:
         == "refs/tags/v1.0.0"
     )
     assert (
-        cli_junit_upload._process_tests_target_branch(
+        ci_cli._process_tests_target_branch(
             context_mock,
             param_mock,
             "main",
@@ -365,7 +367,7 @@ def test_process_tests_target_branch_callback() -> None:
 
     # Test None value
     assert (
-        cli_junit_upload._process_tests_target_branch(
+        ci_cli._process_tests_target_branch(
             context_mock,
             param_mock,
             None,
@@ -374,7 +376,7 @@ def test_process_tests_target_branch_callback() -> None:
     )
 
     # Test empty string
-    assert not cli_junit_upload._process_tests_target_branch(
+    assert not ci_cli._process_tests_target_branch(
         context_mock,
         param_mock,
         "",
@@ -396,7 +398,7 @@ def test_junit_file_not_found_error_message() -> None:
     with runner.isolated_filesystem():
         # Try to run junit-process with a non-existent file
         result = runner.invoke(
-            cli_junit_upload.junit_process,
+            ci_cli.junit_process,
             ["non_existent_junit.xml"],
             env=env,
         )
@@ -410,44 +412,41 @@ def test_junit_file_not_found_error_message() -> None:
         )
 
 
-async def test_process_junit_file_reporting(
-    capsys: pytest.CaptureFixture[str],
+@pytest.mark.respx(base_url="https://api.github.com/")
+def test_scopes_send(
+    respx_mock: respx.MockRouter,
+    tmp_path: pathlib.Path,
 ) -> None:
-    with (
-        mock.patch.object(
-            quarantine,
-            "check_and_update_failing_spans",
-            return_value=0,
-        ),
-        mock.patch.object(upload, "upload"),
-        mock.patch.object(
-            id_generator.RandomIdGenerator,
-            "generate_span_id",
-            return_value=12345678910,
-        ),
-        pytest.raises(SystemExit),
-    ):
-        await cli_junit_upload._process_junit_files(
-            api_url="https://api.mergify.com",
-            token="foobar",  # noqa: S106
-            repository="foo/bar",
-            test_framework=None,
-            test_language=None,
-            tests_target_branch="main",
-            files=(str(REPORT_XML),),
-        )
+    """Test scopes command with all required parameters."""
 
-    captured = capsys.readouterr()
-    assert (
-        captured.out
-        == """🚀 CI Insights · Upload JUnit
-────────────────────────────
-📂 Discovered reports: 1
-🛠️ MERGIFY_TEST_RUN_ID=00000002dfdc1c3e
-🧪 Parsed tests: 2 (✅ passed: 1 | ❌ failed: 1)
-
-🎉 Verdict
-• Status: ✅ OK — all 1 failures are quarantined (ignored for CI status)
-• Exit code: 0
-"""
+    # Create config file
+    scopes_file = tmp_path / "scopes.json"
+    scopes_file.write_text(
+        json.dumps({"base_ref": "main", "scopes": ["backend", "frontend"]}),
     )
+
+    runner = testing.CliRunner()
+
+    post_mock = respx_mock.post(
+        "https://api.mergify.com/v1/repos/owner/repository/pulls/123/scopes",
+        headers={"Authorization": "Bearer test-token"},
+    ).respond(200)
+    result = runner.invoke(
+        ci_cli.scopes_send,
+        [
+            "--pull-request",
+            "123",
+            "--repository",
+            "owner/repository",
+            "--token",
+            "test-token",
+            "--scope",
+            "foobar",
+            "--file",
+            str(scopes_file),
+        ],
+    )
+
+    assert result.exit_code == 0, result.output
+    payload = json.loads(post_mock.calls[0].request.content)
+    assert sorted(payload["scopes"]) == ["backend", "foobar", "frontend"]
